Index: /issm/trunk/src/c/modules/MaxAbsVyx/MaxAbsVyx.cpp
===================================================================
--- /issm/trunk/src/c/modules/MaxAbsVyx/MaxAbsVyx.cpp	(revision 5870)
+++ /issm/trunk/src/c/modules/MaxAbsVyx/MaxAbsVyx.cpp	(revision 5871)
@@ -20,5 +20,5 @@
 	for(i=0;i<elements->Size();i++){
 		Element* element=(Element*)elements->GetObjectByOffset(i);
-		element->MaxAbsVy(&element_maxabsvy,process_units); //go pick up the minimum velocity in the inputs
+		element->MaxAbsVy(&element_maxabsvy,process_units); //go pick up the maximum velocity in the inputs
 	
 		if(i==0)maxabsvy=element_maxabsvy; //initialize maxabsvy
@@ -33,5 +33,5 @@
 
 	#ifdef _PARALLEL_
 	/*Figure out minimum across the cluster: */
 	MPI_Reduce (&maxabsvy,&node_maxabsvy,1,MPI_DOUBLE,MPI_MAX,0,MPI_COMM_WORLD );
 	MPI_Bcast(&node_maxabsvy,1,MPI_DOUBLE,0,MPI_COMM_WORLD);   
@@ -33,5 +33,5 @@
 
 	#ifdef _PARALLEL_
-	/*Figure out minimum across the cluster: */
+	/*Figure out maximum across the cluster: */
 	MPI_Reduce (&maxabsvy,&node_maxabsvy,1,MPI_DOUBLE,MPI_MAX,0,MPI_COMM_WORLD );
 	MPI_Bcast(&node_maxabsvy,1,MPI_DOUBLE,0,MPI_COMM_WORLD);   
